@@ -4,7 +4,7 @@
  * Home page: http://plasma-gate.weizmann.ac.il/Grace/
  * 
  * Copyright (c) 1991-1995 Paul J Turner, Portland, OR
- * Copyright (c) 1996-2001 Grace Development Team
+ * Copyright (c) 1996-2002 Grace Development Team
  * 
  * Maintained by Evgeny Stambulchik <fnevgeny@plasma-gate.weizmann.ac.il>
  * 
@@ -620,6 +620,10 @@ int realloc_graph_plots(int gno, int n)
 int set_graph_type(int gno, int gtype)
 {
     if (is_valid_gno(gno) == TRUE) {
+        if (g[gno].type == gtype) {
+            return RETURN_SUCCESS;
+        }
+        
         switch (gtype) {
         case GRAPH_XY:
         case GRAPH_CHART:
@@ -748,8 +752,31 @@ int get_graph_yscale(int gno)
 int set_graph_xscale(int gno, int scale)
 {
     if (is_valid_gno(gno) == TRUE) {
-        g[gno].xscale = scale;
-        set_dirtystate();
+        if (g[gno].xscale != scale) {
+            int naxis;
+            g[gno].xscale = scale;
+            for (naxis = 0; naxis < MAXAXES; naxis++) {
+                if (is_xaxis(naxis)) {
+                    tickmarks *t;
+                    t = get_graph_tickmarks(gno, naxis);
+                    if (t) {
+                        if (scale == SCALE_LOG) {
+                            if (g[gno].w.xg2 <= 0.0) {
+                                g[gno].w.xg2 = 10.0;
+                            }
+                            if (g[gno].w.xg1 <= 0.0) {
+                                g[gno].w.xg1 = g[gno].w.xg2/1.0e3;
+                            }
+                            t->tmajor = 10.0;
+                            t->nminor = 9;
+                        } else {
+                            t->nminor = 1;
+                        }
+                    }
+                }
+            }
+            set_dirtystate();
+        }
         return RETURN_SUCCESS;
     } else {
         return RETURN_FAILURE;
@@ -759,8 +786,31 @@ int set_graph_xscale(int gno, int scale)
 int set_graph_yscale(int gno, int scale)
 {
     if (is_valid_gno(gno) == TRUE) {
-        g[gno].yscale = scale;
-        set_dirtystate();
+        if (g[gno].yscale != scale) {
+            int naxis;
+            g[gno].yscale = scale;
+            for (naxis = 0; naxis < MAXAXES; naxis++) {
+                if (is_yaxis(naxis)) {
+                    tickmarks *t;
+                    t = get_graph_tickmarks(gno, naxis);
+                    if (t) {
+                        if (scale == SCALE_LOG) {
+                            if (g[gno].w.yg2 <= 0.0) {
+                                g[gno].w.yg2 = 10.0;
+                            }
+                            if (g[gno].w.yg1 <= 0.0) {
+                                g[gno].w.yg1 = g[gno].w.yg2/1.0e3;
+                            }
+                            t->tmajor = 10.0;
+                            t->nminor = 9;
+                        } else {
+                            t->nminor = 1;
+                        }
+                    }
+                }
+            }
+            set_dirtystate();
+        }
         return RETURN_SUCCESS;
     } else {
         return RETURN_FAILURE;
@@ -1319,6 +1369,20 @@ void postprocess_project(int version)
                     set_graph_xinvert(gno, FALSE);
                 }
             }
+            if (version < 50107) {
+                /* Starting with 5.1.7, symskip is honored for all set types */
+                switch (g[gno].p[setno].type) {
+                case SET_BAR:
+                case SET_BARDY:
+                case SET_BARDYDY:
+                case SET_XYHILO:
+                case SET_XYR:
+                case SET_XYVMAP:
+                case SET_BOXPLOT:
+                    g[gno].p[setno].symskip = 0;
+                    break;
+                }
+            }
         }
         for (naxis = 0; naxis < MAXAXES; naxis++) {
 	    tickmarks *t = get_graph_tickmarks(gno, naxis);
