@@ -376,6 +376,9 @@ int initialize_gui(int *argc, char **argv)
     unsigned int i, n_common, n_resol;
     char *display_name = NULL;
 
+    /* Locale settings for GUI */
+    XtSetLanguageProc(NULL, NULL, NULL);
+    
     XtToolkitInitialize();
     app_con = XtCreateApplicationContext();
     
@@ -790,7 +793,7 @@ static Widget CreateMainMenuBar(Widget parent)
     CreateMenuButton(submenupane, "Regression...", 'R', create_reg_frame, NULL);
     CreateMenuButton(submenupane, "Non-linear curve fitting...", 'N', create_nonl_frame, NULL);
     CreateMenuSeparator(submenupane);
-    CreateMenuButton(submenupane, "Cross/auto correlation...", 'C', create_xcor_frame, NULL);
+    CreateMenuButton(submenupane, "Correlation/covariance...", 'C', create_xcor_frame, NULL);
     CreateMenuButton(submenupane, "Digital filter...", 'f', create_digf_frame, NULL);
     CreateMenuButton(submenupane, "Linear convolution...", 'v', create_lconv_frame, NULL);
     CreateMenuSeparator(submenupane);
